
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '32.3.0',
    'branch_nick': 'release-32-LTS',
    'revision_id': '7a033c118633c83dd7d588b4188b457f77f5dedc',
    'revno': 12618
}
